# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import docifier-test
from docifier-test.models.filing import Filing  # noqa: E501
from docifier-test.rest import ApiException

class TestFiling(unittest.TestCase):
    """Filing unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Filing
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = docifier-test.models.filing.Filing()  # noqa: E501
        if include_optional :
            return Filing(
                access_number = '0', 
                symbol = '0', 
                cik = '0', 
                form = '0', 
                filed_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                accepted_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                report_url = '0', 
                filing_url = '0'
            )
        else :
            return Filing(
        )

    def testFiling(self):
        """Test Filing"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
